package X3D::FieldTypes::SFVec4f;

our $VERSION = '0.009';

use X3D::Package 'SFVec4f : SFVec4d { 0 0 0 0 }';

1;
__END__
